Commit Diff


commit - 0c3befa0bd8d4cfd87526fd26b0a5807585fcbde
commit + 7da703f186d37b179a60b2a424d4aa3c4427e5f7
blob - c16b0b9fad6d7416b2b3a90344192508164ab4ed
blob + b9b8fc26d30f731386f8895b32bcb9a9b71a5178
--- src/ngircd/tool.h
+++ src/ngircd/tool.h
@@ -9,14 +9,16 @@
  * Naehere Informationen entnehmen Sie bitter der Datei COPYING. Eine Liste
  * der an comBase beteiligten Autoren finden Sie in der Datei AUTHORS.
  *
- * $Id: tool.h,v 1.1 2001/12/11 21:53:04 alex Exp $
+ * $Id: tool.h,v 1.2 2001/12/12 17:20:33 alex Exp $
  *
  * log.h: Hilfsfunktionen (Header)
  *
  * $Log: tool.h,v $
- * Revision 1.1  2001/12/11 21:53:04  alex
- * Initial revision
+ * Revision 1.2  2001/12/12 17:20:33  alex
+ * - Tool-Funktionen haben nun das Praefix "ngt_".
  *
+ * Revision 1.1.1.1  2001/12/11 21:53:04  alex
+ * - Imported sources to CVS.
  */
 
 
@@ -24,7 +26,7 @@
 #define __tool_h__
 
 
-GLOBAL VOID Trim_Str( CHAR *String );
+GLOBAL VOID ngt_Trim_Str( CHAR *String );
 
 
 #endif
--- src/ngircd/tool.c
+++ src/ngircd/tool.c
@@ -9,14 +9,16 @@
  * Naehere Informationen entnehmen Sie bitter der Datei COPYING. Eine Liste
  * der an comBase beteiligten Autoren finden Sie in der Datei AUTHORS.
  *
- * $Id: tool.c,v 1.1 2001/12/11 21:53:04 alex Exp $
+ * $Id: tool.c,v 1.2 2001/12/12 17:20:33 alex Exp $
  *
  * tool.c: Hilfsfunktionen, ggf. Platformabhaengig
  *
  * $Log: tool.c,v $
- * Revision 1.1  2001/12/11 21:53:04  alex
- * Initial revision
+ * Revision 1.2  2001/12/12 17:20:33  alex
+ * - Tool-Funktionen haben nun das Praefix "ngt_".
  *
+ * Revision 1.1.1.1  2001/12/11 21:53:04  alex
+ * - Imported sources to CVS.
  */
 
 
@@ -29,13 +31,14 @@
 #include <string.h>
 
 #include <exp.h>
-#include "log.h"
+#include "tool.h"
 
 
-GLOBAL VOID Trim_Str( CHAR *String )
+GLOBAL VOID ngt_Trim_Str( CHAR *String )
 {
 	/* Mit Trim_Str() werden fuehrende und folgende Leerzeichen, Tabulatoren
 	 * und Zeilenumbrueche (ASCII 10 und ASCII 13) aus dem String entfernt. */
 	
 	CHAR *start, *ptr;
 
@@ -52,7 +55,7 @@ GLOBAL VOID Trim_Str( CHAR *String )
 	*(++ptr) = '\0';
 
 	memmove( String, start, strlen( start ) + 1 );
-} /* Trim_Str */
+} /* ngt_Trim_Str */
 
 
 /* -eof- */
@@ -29,13 +31,14 @@
 {
-	/* Mit Trim_Str() werden fuehrende und folgende Leerzeichen, Tabulatoren
-	 * und Zeilenumbrueche (ASCII 10 und ASCII 13) aus dem String entfernt. */
+	/* Mit ngt_Trim_Str() werden fuehrende und folgende Leerzeichen,
+	 * Tabulatoren und Zeilenumbrueche (ASCII 10 und ASCII 13) aus
+	 * dem String entfernt. */
 	
 	CHAR *start, *ptr;
blob - 2f2614671868a46f6ae03fccc4f2b5761e9c2b2b
blob + 70c09588536f72530e86ca753912d59fcfff7d4b